/* Casefolding mapping for UTF-8 substrings (locale dependent).
   Copyright (C) 2009-2020 Free Software Foundation, Inc.
   Written by Bruno Haible <bruno@clisp.org>, 2009.

   This program is free software: you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published
   by the Free Software Foundation; either version 3 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <https://www.gnu.org/licenses/>.  */

#include <config.h>

/* Specification.  */
#include "unicase.h"

#include <errno.h>
#include <stddef.h>
#include <stdlib.h>

#include "unicase/unicasemap.h"
#include "unicase/special-casing.h"
#include "unicase/casefold.h"

#define FUNC u8_ct_casefold
#define UNIT uint8_t
#define U_CASEMAP u8_casemap
#define U_NORMALIZE u8_normalize
#include "u-ct-casefold.h"
